The two types of communications are end or a config, This is an enum that reflects that reality
The interaction loop
This function is the one that sends the kill signals to the processes It waits for a Config to be sent to it to start blocking.